==> iReport-0.0.2.zip: iReport-0.0.2/src/com/businesslogic/ireport/StaticTextReportElement.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package com.businesslogic.ireport;

import com.businesslogic.ireport.ui.*;
import com.businesslogic.ireport.util.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.ui.*;

public class StaticTextReportElement extends TextReportElement 
{
	public StaticTextReportElement(int x, int y, int width, int height, Brush hached)
	{
		super(x,y,width,height,hached);
		this.text = "StaticText";
	}
	
	public ReportElement cloneMe()
	{
		StaticTextReportElement newReportElement = new StaticTextReportElement(position.x, position.y, width, height, hached);
		newReportElement.name = new String(name);
		newReportElement.bgcolor = bgcolor;
		newReportElement.fgcolor = fgcolor;
		newReportElement.text = text;
		newReportElement.font = new Font( font.getFontMetrics() );
		return newReportElement;
	}
}

==> iReport-0.0.5.zip: iReport-0.0.5/src/com/businesslogic/ireport/StaticTextReportElement.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package com.businesslogic.ireport;

import com.businesslogic.ireport.ui.*;
import com.businesslogic.ireport.util.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.ui.*;

public class StaticTextReportElement extends TextReportElement 
{
	public StaticTextReportElement(int x, int y, int width, int height, Brush hached)
	{
		super(x,y,width,height,hached);
		this.text = "StaticText";
	}
	
	public ReportElement cloneMe()
	{
		StaticTextReportElement newReportElement = new StaticTextReportElement(position.x, position.y, width, height, hached);
		newReportElement.name = new String(name);
		newReportElement.bgcolor = bgcolor;
		newReportElement.fgcolor = fgcolor;
		newReportElement.text = text;
		newReportElement.font = null;
		copyTextPropertiesTo(newReportElement);
		return newReportElement;
	}
}
